@@ -2,12 +2,19 @@ summary <- R6::R6Class("summary",
   public = list(
     initialize = function(filter, failed_ions, passed_ions) {
       stopifnot(any(class(filter) == "character"))
-      stopifnot(any(class(failed_ions) == c("numeric", "character")))
-      stopifnot(any(class(passed_ions) == c("numeric", "character")))
 
-      private$filter <- filter
-      private$failed_ions <- failed_ions
-      private$passed_ions <- passed_ions
+      if (is.null(failed_ions)) {
+        private$filter <- filter
+        private$failed_ions <- c()
+        private$passed_ions <- passed_ions
+      } else {
+        stopifnot(any(class(failed_ions) == c("numeric", "character")))
+        stopifnot(any(class(passed_ions) == c("numeric", "character")))
+
+        private$filter <- filter
+        private$failed_ions <- failed_ions
+        private$passed_ions <- passed_ions
+      }
     },
     summarize = function(x) {
       l <- length(private$failed_ions)
