@@ -1,10 +1,9 @@
 test_that("test that filter_pactr-class constructs properly", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory, peak_table_name))
 
   mpactr_class <- mpactr$new(
@@ -21,17 +20,14 @@ test_that("test that filter_pactr-class constructs properly", {
 })
 
 test_that("get_log returns an error 
-when an incorrect fitler argument is provided", {
-
+when an incorrect filter argument is provided", {
 
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
 
-
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
 
@@ -47,14 +43,13 @@ when an incorrect fitler argument is provided", {
           })
 
 test_that("get_log returns an error when the 
-fitler argument provided has not yet been run (e.g., not in the log)", {
+filter argument provided has not yet been run (e.g., not in the log)", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
 
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
 
@@ -68,15 +63,13 @@ fitler argument provided has not yet been run (e.g., not in the log)", {
             expect_error(filter_class$get_log(filter = "mispicked"), er)
           })
 
-test_that("get_log returns the correct fitler summary list", {
-
+test_that("get_log returns the correct filter summary list", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
 
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory, peak_table_name))
 
   mpactr_class <- mpactr$new(
@@ -101,14 +94,13 @@ test_that("get_log returns the correct fitler summary list", {
   expect_equal(length(mispicked_summary$passed_ions), 1233)
 })
 
-test_that("get_log returns the correct fitler
+test_that("get_log returns the correct filter
  summary list when group is supplied", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
 
@@ -132,12 +124,11 @@ test_that("get_log returns the correct fitler
 
 test_that("get_mispicked_ions returns error if 
 check_mismatched_peaks has not been called", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
             mpactr_class <- mpactr$new(
@@ -153,12 +144,11 @@ check_mismatched_peaks has not been called", {
 
 test_that("get_mispicked_ions correctly returns
  the check_mismatched_peaks list", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
 
@@ -186,12 +176,11 @@ test_that("get_mispicked_ions correctly returns
 
 
 test_that("get_group_averages calculates a group table", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
 
@@ -216,9 +205,7 @@ test_that("get_group_averages calculates a group table", {
   expect_equal(class(avgs), c("data.table", "data.frame"))
   expect_equal(nrow(avgs), (1233 * 6))
 
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
 
@@ -249,13 +236,11 @@ test_that("get_group_averages calculates a group table", {
 })
 
 test_that("get_cv returns the cv filter has been applied", {
-
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
 
@@ -287,12 +272,11 @@ test_that("get_cv returns the cv filter has been applied", {
 })
 
 test_that("Test that mpactr can be printed from the filter-pactR class", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
 
@@ -306,13 +290,11 @@ test_that("Test that mpactr can be printed from the filter-pactR class", {
 })
 
 test_that("is_filter_run correctly assesses if a filter has been run", {
-
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
 
@@ -342,13 +324,12 @@ test_that("is_filter_run correctly assesses if a filter has been run", {
 })
 
 test_that("get_log returns an error when 
-an incorrect fitler argument is provided", {
+an incorrect filter argument is provided", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
             mpactr_class <- mpactr$new(
@@ -361,14 +342,13 @@ an incorrect fitler argument is provided", {
                          "`filter` must be one of mpactr's")
           })
 
-test_that("get_log returns an error when the fitler
+test_that("get_log returns an error when the filter
  argument provided has not yet been run (e.g., not in the log)", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
             mpactr_class <- mpactr$new(
@@ -381,13 +361,12 @@ test_that("get_log returns an error when the fitler
             expect_error(filter_class$get_log(filter = "mispicked"), err_msg)
           })
 
-test_that("get_log returns the correct fitler summary list", {
+test_that("get_log returns the correct filter summary list", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
   mpactr_class <- mpactr$new(
@@ -410,12 +389,11 @@ test_that("get_log returns the correct fitler summary list", {
 
 test_that("get_mispicked_ions returns error if 
 check_mismatched_peaks has not been called", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
             mpactr_class <- mpactr$new(
@@ -431,12 +409,11 @@ check_mismatched_peaks has not been called", {
 
 test_that("get_mispicked_ions correctly 
 returns the check_mismatched_peaks list", {
+            limit_cores()
             directory <- "exttestdata"
             peak_table_name <- "102623_peaktable_coculture_simple.csv"
             meta_data_name <- "102623_metadata_correct.csv"
-            meta <- data.table(read_csv(test_path(directory,
-                                                  meta_data_name),
-                                        show_col_types = FALSE))
+            meta <- fread(test_path(directory, meta_data_name))
             pt_list <- progenesis_formatter(test_path(directory,
                                                       peak_table_name))
             mpactr_class <- mpactr$new(
@@ -461,12 +438,11 @@ returns the check_mismatched_peaks list", {
 
 
 test_that("get_group_averages calculates a group table", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
   mpactr_class <- mpactr$new(
@@ -508,12 +484,11 @@ test_that("get_group_averages calculates a group table", {
 })
 
 test_that("get_cv returns the cv filter has been applied", {
+  limit_cores()
   directory <- "exttestdata"
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
   meta_data_name <- "102623_metadata_correct.csv"
-  meta <- data.table(read_csv(test_path(directory,
-                                        meta_data_name),
-                              show_col_types = FALSE))
+  meta <- fread(test_path(directory, meta_data_name))
   pt_list <- progenesis_formatter(test_path(directory,
                                             peak_table_name))
   mpactr_class <- mpactr$new(
