@@ -1,9 +1,8 @@
 test_that("plot_QC_Tree generates the correct plot", {
-
+  limit_cores()
   peak_table_name <- "102623_peaktable_coculture_simple.csv"
-  meta <- data.table(read_csv(test_path("exttestdata",
-                                        "102623_metadata_correct.csv"),
-                              show_col_types = FALSE))
+  meta <- fread(test_path("exttestdata",
+                          "102623_metadata_correct.csv"))
   pt_list <- progenesis_formatter(test_path("exttestdata", peak_table_name))
 
   mpactr_class <- mpactr$new(
@@ -28,6 +27,5 @@ test_that("plot_QC_Tree generates the correct plot", {
   graph_qc_pactr_class <- graph_qc_pactr$new(filter_class)
   graph_qc_pactr_class$generate_QC_Summary()
   plot <- graph_qc_pactr_class$plot_QC_Tree()
-
-  expect_equal(class(plot), c("gg", "ggplot"))
+  expect_true(is_ggplot(plot))
 })
